/* Header file:  nbigsys.hs					     */

/* Geometry is [NM][NM][NS] with NS = systolic pipe length (even),	*/
/* NB = NM*NS,   NM*NM*NS >= physical size.				*/

extern int NM;	/* Number of pipes in each dimension   		*/
extern int NS;	/* Number of entries in systolic pipe >= 4	*/
extern int SS;	/* Number of systolic steps = NS/2     		*/
extern int NB;	/* Number of bodies in system  			*/
extern float G;	/* Gravitational constant			*/

#define TWOPI      6.2831853f

/* Particles, and pairs of particles.  All processors have particle	*/
/* states.  Some variables could be overloaded. 			*/

extern shape [][][]pair;	/* Will be [NM][NM][NS]	*/

/* All parallel variables are declared as pointers so 'pair' can be dynamic. */
/* State variables will be allocated as x0[3],...;  w, m, ... are floats     */

/* x0, x1 - current, new positions;	v0, v1 - current, new velocities */
/* m - mass;		mi,mj - scaled mass;	ac - acceleration	 */
/* w, wv, ax- working							 */
/* xm0 - conveyor (moving) positions; 3 entries	       \		 */
/* xm1 - conveyor (moving) positions; 3 entries		\ vector of	 */
/* acm - conveyor (moving) accelerations; 3 entries	/ 10 entries	 */
/* mmj - conveyor (moving) scaled masses; 1 entry      /		 */


extern float:pair *x0, *x1, *v0, *v1, *m, *mi, *mj, *ac, *ax, *w, *wv,
                  *x0j, *xm0, *xm1, *acm, *mmj;


/* i - row number;    j - column number;    k - pipe position	*/

extern int:pair *i, *j, *k;

/* diag - processor is on diagonal			*/
/* act  - processor is active pair (off-diag)		*/

extern bool:pair *diag, *act;

/*Data sizes for allocation, communication */

extern int fsz, isz, bsz, vsz, cvsz;


/* These are not used, but introduced for compatibility */

extern float:pair  *xm, *am, *r0, *r0s, *mjs, *d0, *d0s;
extern int vsz2;


/* Print x-components of xx in nx by nx pipes (for testing). */

void print_x(char lbl[], float:current *xx, int nx);

















